@@ -16,7 +16,6 @@
 #include <QContextMenuEvent>
 
 #include <KLocalizedString>
-#include <KNotification>
 
 #include "breakpointdetails.h"
 #include "../breakpoint/breakpoint.h"
@@ -49,8 +48,6 @@ public:
     QAction* breakpointEnableAllAction = nullptr;
     QAction* breakpointRemoveAll = nullptr;
     QAbstractProxyModel* proxyModel = nullptr;
-    QMap<QString, size_t> breakpointErrorMessages;
-    bool breakpointErrorMessageVisibile = false;
 };
 
 BreakpointWidget::BreakpointWidget(IDebugController *controller, QWidget *parent)
@@ -71,6 +68,20 @@ BreakpointWidget::BreakpointWidget(IDebugController *controller, QWidget *parent
     d->breakpointsView->setSelectionBehavior(QAbstractItemView::SelectRows);
     d->breakpointsView->setSelectionMode(QAbstractItemView::SingleSelection);
     d->breakpointsView->setRootIsDecorated(false);
+    // PlaceholderItemProxyModel supports only flat models. Expanding the placeholder item
+    // triggers an assertion failure in PlaceholderItemProxyModel::rowCount(). Forbid expanding
+    // items to prevent it. None of the items has children, so expanding is useless anyway.
+    d->breakpointsView->setItemsExpandable(false);
+
+    // Enable uniform row height tree view optimizations. The checkbox in the EnableColumn makes each
+    // non-placeholder row height noticeably greater than the placeholder row height. But the several-pixel
+    // vertical space waste for the single placeholder row is well justified by less CPU time spent on calculating
+    // row heights. The documentation for the QTreeView::uniformRowHeights property even spells out the
+    // implementation details: "The height is obtained from the first item in the view. It is updated when the data
+    // changes on that item." These documentation guarantees are perfect for breakpointsView: if there is only a
+    // single placeholder item in the tree, its row height is used as the row height; when a non-placeholder item
+    // is added, the data changes and the greater non-placeholder first row height becomes used as the row height.
+    d->breakpointsView->setUniformRowHeights(true);
 
     auto detailsContainer = new QGroupBox(i18n("Breakpoint Details"), this);
     auto detailsLayout = new QVBoxLayout(detailsContainer);
@@ -99,10 +110,6 @@ BreakpointWidget::BreakpointWidget(IDebugController *controller, QWidget *parent
             &BreakpointModel::hit,
             this, &BreakpointWidget::breakpointHit);
 
-    connect(d->debugController->breakpointModel(),
-            &BreakpointModel::error,
-            this, &BreakpointWidget::breakpointError);
-
     setupPopupMenu();
 }
 
@@ -298,57 +305,6 @@ void BreakpointWidget::breakpointHit(int row)
         | QItemSelectionModel::ClearAndSelect);
 }
 
-void BreakpointWidget::breakpointError(int row, const QString& msg)
-{
-    Q_UNUSED(row);
-
-    Q_D(BreakpointWidget);
-
-    // if the error popup is still visible only queue the message, to avoid spam
-    if (d->breakpointErrorMessageVisibile) {
-        d->breakpointErrorMessages[msg]++;
-        return;
-    }
-
-    showBreakpointError(msg);
-}
-
-void BreakpointWidget::breakpointErrorPopupClosed()
-{
-    Q_D(BreakpointWidget);
-
-    d->breakpointErrorMessageVisibile = false;
-
-    if (d->breakpointErrorMessages.isEmpty()) {
-        // no messages queued, do nothing
-        return;
-    }
-
-    QString errorMsg;
-
-    for (auto it = d->breakpointErrorMessages.constBegin(); it != d->breakpointErrorMessages.constEnd(); ++it) {
-        if (!errorMsg.isEmpty()) {
-            errorMsg += QLatin1Char('\n');
-        }
-        errorMsg += i18np("%2", "%2 (repeated %1 times)", it.value(), it.key());
-    }
-
-    d->breakpointErrorMessages.clear();
-
-    showBreakpointError(errorMsg);
-}
-
-void BreakpointWidget::showBreakpointError(const QString& msg)
-{
-    Q_D(BreakpointWidget);
-
-    auto * const errorPopup = new KNotification(QStringLiteral("BreakpointError"));
-    connect(errorPopup, &KNotification::closed, this, &BreakpointWidget::breakpointErrorPopupClosed);
-    errorPopup->setText(msg);
-    errorPopup->sendEvent();
-    d->breakpointErrorMessageVisibile = true;
-}
-
 void BreakpointWidget::slotOpenFile(const QModelIndex& breakpointIdx)
 {
     Q_D(BreakpointWidget);
