@@ -61,6 +61,21 @@ public:
     };
 
 public:
+    enum class ToolView : signed char {
+        None, ///< no tool view
+        Build, ///< Build output tool view
+        Debug ///< Debug output tool view
+    };
+
+    /**
+     * @return the ID of a tool view that should be raised in the Code area when this debug session ends
+     *
+     * The default implementation returns ToolView::Debug in order to show the output of the debuggee.
+     * A derived class may want to override and return ToolView::None if the debug
+     * session produces no output, or ToolView::Build if building the debuggee fails.
+     */
+    [[nodiscard]] virtual ToolView toolViewToRaiseAtEnd() const;
+
     /**
      * Current state of the debug session
      */
@@ -139,7 +154,6 @@ Q_SIGNALS:
     void showStepInSource(const QUrl& file, int line, const QString &addr);
     void showStepInDisassemble(const QString &addr);
     void clearExecutionPoint();
-    void finished();
 
     void raiseFramestackViews();
 
