@@ -1,23 +1,9 @@
 /*
- * This file is part of KDevelop
- * Copyright 2014 Alex Richardson <arichardson.kde@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2014 Alex Richardson <arichardson.kde@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
+
 #include "configpage.h"
 
 #include <KConfigDialogManager>
@@ -88,6 +74,23 @@ void ConfigPage::initConfigManager()
     if (d->configManager) {
         d->configManager->addWidget(this);
     }
+
+    if (needsResetDuringInitialization()) {
+        reset();
+    }
+}
+
+bool ConfigPage::needsResetDuringInitialization() const
+{
+    // Potentially slow but safe default: makes sure all widgets are in the correct state.
+    // Many Kate classes derived from KTextEditor::ConfigPage call reset() in their constructors.
+    // TODO: update KDevelop classes derived from KTextEditor::ConfigPage one by one as follows:
+    // 1) override needsResetDuringInitialization() to return false;
+    // 2) call reset() in constructor(s) if needed.
+    // Once all KDevelop and KDevelop plugin ConfigPage-derived classes return false from
+    // needsResetDuringInitialization() (verify by making this function pure virtual), remove
+    // needsResetDuringInitialization() and its overrides, never call reset() in initConfigManager().
+    return true;
 }
 
 KCoreConfigSkeleton* ConfigPage::configSkeleton() const
@@ -143,3 +146,5 @@ ConfigPage::ConfigPageType ConfigPage::configPageType() const
 }
 
 } // namespace KDevelop
+
+#include "moc_configpage.cpp"
