@@ -1,23 +1,11 @@
-/* This  is part of KDevelop
-    Copyright 2002-2005 Roberto Raggi <roberto@kdevelop.org>
-    Copyright 2006 Adam Treat <treat@kde.org>
-    Copyright 2006 Hamish Rodda <rodda@kde.org>
-    Copyright 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
+/*
+    SPDX-FileCopyrightText: 2002-2005 Roberto Raggi <roberto@kdevelop.org>
+    SPDX-FileCopyrightText: 2006 Adam Treat <treat@kde.org>
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "classmemberdeclaration.h"
 #include "classmemberdeclarationdata.h"
@@ -27,14 +15,13 @@
 namespace KDevelop {
 ClassMemberDeclarationData::ClassMemberDeclarationData()
     : m_accessPolicy(Declaration::Public)
-    , m_alignOfExponent(ClassMemberDeclarationData::MaxAlignOfExponent)
     , m_isStatic(false)
     , m_isAuto(false)
     , m_isFriend(false)
     , m_isRegister(false)
     , m_isExtern(false)
     , m_isMutable(false)
-    , m_sizeOf(-1)
+    , m_bitWidth(ClassMemberDeclaration::NotABitField)
     , m_bitOffsetOf(-1)
 {
 }
@@ -154,16 +141,6 @@ void ClassMemberDeclaration::setStorageSpecifiers(StorageSpecifiers specifiers)
     d->m_isMutable = specifiers & MutableSpecifier;
 }
 
-int64_t ClassMemberDeclaration::sizeOf() const
-{
-    return d_func()->m_sizeOf;
-}
-
-void ClassMemberDeclaration::setSizeOf(int64_t sizeOf)
-{
-    d_func_dynamic()->m_sizeOf = sizeOf;
-}
-
 int64_t ClassMemberDeclaration::bitOffsetOf() const
 {
     return d_func()->m_bitOffsetOf;
@@ -174,25 +151,13 @@ void ClassMemberDeclaration::setBitOffsetOf(int64_t bitOffsetOf)
     d_func_dynamic()->m_bitOffsetOf = bitOffsetOf;
 }
 
-int64_t ClassMemberDeclaration::alignOf() const
+int ClassMemberDeclaration::bitWidth() const
 {
-    if (d_func()->m_alignOfExponent == ClassMemberDeclarationData::MaxAlignOfExponent) {
-        return -1;
-    } else {
-        return Q_INT64_C(1) << d_func()->m_alignOfExponent;
-    }
+    return d_func()->m_bitWidth;
 }
 
-void ClassMemberDeclaration::setAlignOf(int64_t alignedTo)
+void ClassMemberDeclaration::setBitWidth(int bitWidth)
 {
-    if (alignedTo <= 0) {
-        d_func_dynamic()->m_alignOfExponent = ClassMemberDeclarationData::MaxAlignOfExponent;
-        return;
-    }
-
-    unsigned int alignOfExponent = 0;
-    while (alignedTo >>= 1)
-        alignOfExponent++;
-    d_func_dynamic()->m_alignOfExponent = alignOfExponent;
+    d_func_dynamic()->m_bitWidth = bitWidth;
 }
 }
