@@ -10,15 +10,20 @@
 #define IDEALDOCKWIDGET_H
 
 #include <QDockWidget>
-#include "idealcontroller.h"
+
+class QMainWindow;
 
 namespace Sublime {
+class Area;
+class IdealController;
+class View;
+
 class IdealDockWidget : public QDockWidget
 {
     Q_OBJECT
 
 public:
-    IdealDockWidget(IdealController *controller, Sublime::MainWindow *parent);
+    explicit IdealDockWidget(IdealController* controller, QMainWindow* parent);
     ~IdealDockWidget() override;
 
     Area *area() const;
@@ -30,6 +35,11 @@ public:
     Qt::DockWidgetArea dockWidgetArea() const;
     void setDockWidgetArea(Qt::DockWidgetArea dockingArea);
 
+    /**
+     * Activate the ancestor top-level window, raise and focus this widget.
+     */
+    void activate();
+
 public Q_SLOTS:
     /// The IdealToolButton also connects to this slot to show the same context menu.
     void contextMenuRequested(const QPoint &point);
