@@ -1,25 +1,10 @@
 /*
- * KDevelop C++ Language Support
- *
- * Copyright 2008 Hamish Rodda <rodda@kde.org>
- * Copyright 2012 Miha Čančula <miha@noughmad.eu>
- * Copyright 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2008 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2012 Miha Čančula <miha@noughmad.eu>
+    SPDX-FileCopyrightText: 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "clangclasshelper.h"
 
@@ -35,6 +20,7 @@
 #include <language/codegen/codedescription.h>
 #include <custom-definesandincludes/idefinesandincludesmanager.h>
 #include <project/projectmodel.h>
+#include <serialization/indexedstringview.h>
 #include <util/path.h>
 
 #include <QTemporaryFile>
@@ -148,13 +134,13 @@ QString includeDirectiveArgumentFromPath(const Path& file,
     const auto includeManager = IDefinesAndIncludesManager::manager();
     const auto filePath = file.toLocalFile();
     const auto projectModel = ICore::self()->projectController()->projectModel();
-    auto item = projectModel->itemForPath(IndexedString(filePath));
+    auto item = projectModel->itemForPath(IndexedStringView{filePath});
 
     if (!item) {
         // try the folder where the file is placed and guess includes from there
         // prefer target over file
-        const auto folderPath = IndexedString(file.parent().toLocalFile());
-        clangDebug() << "File not known, guessing includes from items in folder:" << folderPath.str();
+        const IndexedStringView folderPath{file.parent().toLocalFile()};
+        clangDebug() << "File not known, guessing includes from items in folder:" << folderPath;
 
         // default to the folder, if no targets or files
         item = projectModel->itemForPath(folderPath);
