@@ -1,22 +1,8 @@
-/* KDevelop CMake Support
- *
- * Copyright 2017 Aleix Pol Gonzalez <aleixpol@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2017 Aleix Pol Gonzalez <aleixpol@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <cmakeserver.h>
 #include <tests/autotestshell.h>
@@ -40,7 +26,7 @@ public:
     {
         QLoggingCategory::setFilterRules(QStringLiteral("default.debug=true\nkdevelop.projectmanagers.cmake.debug=true\n"));
 
-        AutoTestShell::init();
+        AutoTestShell::init({ "KDevCMakeManager", "KDevCMakeBuilder", "KDevMakeBuilder", "KDevStandardOutputView" });
         TestCore::initialize();
     }
 
@@ -53,7 +39,7 @@ private Q_SLOTS:
         QVERIFY(!versionStr.isEmpty());
         const auto version = QVersionNumber::fromString(versionStr);
         QVERIFY(!version.isNull());
-        const bool versionWithServer = version >= QVersionNumber(3, 8);
+        const bool versionWithServer = (version >= QVersionNumber(3, 8) && version < QVersionNumber(3, 20));
         if (!versionWithServer)
             QSKIP("cmake server not supported");
     }
