@@ -14,16 +14,23 @@
 
 #include <interfaces/iplugin.h>
 #include <interfaces/istatus.h>
-#include <interfaces/iuicontroller.h>
 
 #include <QHash>
 
+#include <memory>
+
 class QDBusServiceWatcher;
 
+namespace KDevelop {
+class IDebugSession;
+}
+
 namespace KDevMI {
+class IToolViewFactoryHolder;
 class MIAttachProcessJob;
 class MIDebugSession;
 class DBusProxy;
+
 class MIDebuggerPlugin : public KDevelop::IPlugin, public KDevelop::IStatus
 {
     Q_OBJECT
@@ -38,13 +45,6 @@ public:
 
     MIDebugSession* createSession();
 
-    virtual void setupToolViews() = 0;
-    /**
-     * The implementation should be sure it's safe to call
-     * even when tool views are already unloaded.
-     */
-    virtual void unloadToolViews() = 0;
-
 //BEGIN IStatus
 public:
     QString statusName() const override;
@@ -58,7 +58,6 @@ Q_SIGNALS:
 //END IStatus
 
 Q_SIGNALS:
-    void reset();
     void raiseDebuggerConsoleViews();
 
 protected Q_SLOTS:
@@ -71,6 +70,8 @@ protected Q_SLOTS:
 #endif
 
 protected:
+    using ToolViewFactoryHolderPtr = std::unique_ptr<IToolViewFactoryHolder>;
+
     void setupActions();
     void setupDBus();
 
@@ -79,41 +80,15 @@ protected:
 
 private:
     [[nodiscard]] virtual MIDebugSession* createSessionObject() = 0;
+    [[nodiscard]] virtual ToolViewFactoryHolderPtr createToolViewFactoryHolder() = 0;
+
+    [[nodiscard]] ToolViewFactoryHolderPtr reuseOrCreateToolViewFactoryHolder(KDevelop::IDebugSession* previousSession);
 
     QHash<QString, DBusProxy*> m_drkonqis;
     const QString m_displayName;
     QDBusServiceWatcher* m_watcher = nullptr;
 };
 
-template<class T, class Plugin = MIDebuggerPlugin>
-class DebuggerToolFactory : public KDevelop::IToolViewFactory
-{
-public:
-    DebuggerToolFactory(Plugin * plugin, const QString &id, Qt::DockWidgetArea defaultArea)
-    : m_plugin(plugin), m_id(id), m_defaultArea(defaultArea)
-    {}
-
-    QWidget* create(QWidget *parent = nullptr) override
-    {
-        return new T(m_plugin, parent);
-    }
-
-    QString id() const override
-    {
-        return m_id;
-    }
-
-    Qt::DockWidgetArea defaultPosition() const override
-    {
-        return m_defaultArea;
-    }
-
-private:
-    Plugin * m_plugin;
-    QString m_id;
-    Qt::DockWidgetArea m_defaultArea;
-};
-
 } // end of namespace KDevMI
 
 #endif // MIDEBUGGERPLUGIN_H
